Changelog
=========

1.2.0
-----
 - better interaction with Microsoft Active Directory (AD)
 - simplified management interface components
 - added support for Python 3.11

1.1.7
-----
 - remove spaces from DN when used as query base

1.1.6
-----
 - PyAMS_security interfaces refactoring
 - added support for Python 3.10

1.1.5
-----
 - use Python 3 syntax in super() calls
 - Pylint cleanups

1.1.4
-----
 - use constant for principal ID formatter
 - added doctests

1.1.3
-----
 - updated menus context

1.1.2
-----
 - updated add and edit forms title

1.1.1
-----
 - updated add menus registration for last PyAMS_zmi release

1.1.0
-----
 - removed support for Python < 3.7
 - handle single values in LDAP entry column renderer

1.0.3
-----
 - removed Travis-CI configuration

1.0.2
-----
 - updated "find_principals()" method to use new "exact_match" argument

1.0.1
-----
 - code cleanup, added strings constants to reduce duplicated code

1.0.0
-----
 - initial release
